//
//  GradeView.swift
//  UIGrades
//
//  Created by Joe Gregg on 11/5/22.
//

import SwiftUI

struct GradeView: View {
    @Environment(\.managedObjectContext) var moc
    @FetchRequest(sortDescriptors: []) var quizzes : FetchedResults<Quiz>
    @FetchRequest(sortDescriptors: [SortDescriptor(\.last_name),SortDescriptor(\.first_name)]) var students : FetchedResults<Student>
    @State var quiz : Quiz?
    @State var student : Student?
    var body: some View {
        if quizzes.count == 0 {
            Text("No quizzes available to display")
        } else if students.count == 0 {
            Text("No students available to display")
        } else {
            VStack {
                Picker(selection: $quiz,label:Text("Select a quiz:")) {
                    ForEach(quizzes) { q in
                        Text(q.name ?? "Unknown").tag(q.self as Quiz?)
                    }
                }
                Picker(selection: $student,label:Text("Select a student:")) {
                    ForEach(students) { s in
                        Text("\(s.first_name ?? "Unknown") \(s.last_name ?? "Unknown")").tag(s.self as Student?)
                    }
                }
                Spacer()
                if let q = quiz, let s = student {
                    let g = getGrade(quiz: q, student: s)
                    GradeDetailView(grade: g,student: s,quiz: q)
                }
                Spacer()
            }.onAppear {
                quiz = quizzes.first
                student = students.first
            }
        }
    }
    
    func getGrade(quiz q : Quiz,student s : Student) -> Grade! {
        let sPred = NSPredicate(format: "student.id == %@", s.id! as NSUUID)
        let qPred = NSPredicate(format: "quiz.id == %@", q.id! as NSUUID)
        let request = Grade.fetchRequest()
        request.predicate = NSCompoundPredicate(andPredicateWithSubpredicates: [sPred,qPred])
        request.sortDescriptors = []
        var g : Grade! = nil
        do {
            let grades =  try moc.fetch(request)
            if grades.count > 0 {
                g = grades[0]
            }
        } catch {
                
        }
        return g
    }
}

struct GradeView_Previews: PreviewProvider {
    static var dataController = DataController()
    static var previews: some View {
        GradeView().environment(\.managedObjectContext, dataController.container.viewContext)
    }
}
