//
//  ContentView.swift
//  UIGrades
//
//  Created by Joe Gregg on 11/4/22.
//

import SwiftUI

struct StudentView: View {
    @Environment(\.managedObjectContext) var moc
    @FetchRequest(sortDescriptors: [SortDescriptor(\.last_name),SortDescriptor(\.first_name)]) var students : FetchedResults<Student>
    @State var first_name : String = ""
    @State var last_name : String = ""
    var body: some View {
        VStack {
            List {
                ForEach(students) { student in
                    Text("\(student.first_name ?? "Unknown") \(student.last_name ?? "Unknown")")
                }.onDelete(perform: delete)
            }
            HStack {
                Text("First Name:")
                TextField("",text:$first_name).disableAutocorrection(true).textFieldStyle(.roundedBorder)
            }
            HStack {
                Text("Last Name:")
                TextField("",text:$last_name).disableAutocorrection(true).textFieldStyle(.roundedBorder)
            }
            Button("Add Student") {
                let student = Student(context: moc)
                student.id = UUID()
                student.last_name = last_name
                student.first_name = first_name
                try? moc.save()
            }
        }
    }
    
    func delete(at offsets: IndexSet) {
        offsets.forEach { i in
            moc.delete(students[i])
            try? moc.save()
        }
    }
}

struct ContentView_Previews:
    

PreviewProvider {
    static var dataController = DataController()
    static var previews: some View {
        StudentView().environment(\.managedObjectContext, dataController.container.viewContext)
    }
}
